@@ -52,6 +52,13 @@ def publish(session):
     session.run('flit', 'publish')
 
 
+@nox.session(python=[DEFAULT_PYTHON])
+def typecheck(session):
+    """Check types."""
+    session.install('-U', '.[dev]')
+    session.run('sh', '-c', 'pyright --outputjson 2>/dev/null | json2nt', external=True)
+
+
 @nox.session(python=[DEFAULT_PYTHON])
 def render_readme(session):
     """Generate README.md from templates/README.md.wz."""
